import { getPaths, getStylePath } from './utils';
import { build } from 'esbuild';
import { sassPlugin } from 'esbuild-sass-plugin';
import { format } from 'prettier';
import Root from './root';
import { writeFileSync } from 'node:fs';

export const buildPage = async (page: string) => {
  const { pagePath, tmpJsPath, pageOutputHtmlPath } = getPaths(page);

  await build({
    entryPoints: [pagePath],
    bundle: true,
    outfile: tmpJsPath,
    jsxImportSource: '@kitajs/html',
    minify: true,
    platform: 'node',
    external: ['esbuild'],
    plugins: [
      sassPlugin({
        filter: /\.module\.scss$/,
        type: 'local-css',
      }),
      sassPlugin({
        filter: /\.scss$/,
        type: 'css',
      }),
    ],
  });

  const { default: Page } = await import(tmpJsPath);
  const html = Page.default();
  let stylePaths: string[] = getStylePath(tmpJsPath, pageOutputHtmlPath);

  const formattedHtml = await format(
    <Root title="My App" stylePaths={stylePaths} scriptPaths={[]}>
      {html}
    </Root>,
    { parser: 'html' },
  );

  writeFileSync(pageOutputHtmlPath, formattedHtml);
};
